#!/bin/sh
#
# loader for Forte for Java
#
# Copyright (c) 1997-2000 Sun Microsystems, Inc. All rights reserved.
# Use is subject to license terms.
#

#
# customization
#

# the value set here can be overriden by $JAVA_PATH or the -jdkhome switch
jdkhome=""

jreflags="-Xmx96m"

#
# end of customization 
#


PRG=$0

PATH=/bin:/usr/bin:$PATH
export PATH

#
# resolve symlinks
#

while [ -h "$PRG" ]; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '^.*-> \(.*\)$'`
    if expr "$link" : '^/' > /dev/null; then
	PRG="$link"
    else
	PRG="`dirname $PRG`/$link"
    fi
done

progdir=`dirname $PRG`
progname=`basename $0`

ffjhome="$progdir/.."

# absolutize ffjhome

oldpwd=`pwd` ; cd ${ffjhome}; ffjhome=`pwd`; cd $oldpwd; unset oldpwd

thread_flag=""

jargs=${jreflags}
jargs="$jargs -Dnetbeans.home=$ffjhome"
jargs="$jargs -Djava.security.policy=$ffjhome/bin/forte4j.policy"

args=""

prefixcp=""
postfixcp=""

userdir=""

updater=com.netbeans.developer.updater.UpdaterFrame
ide=com.netbeans.developer.Main

#
# defaults
#

# if JAVA_PATH is set it overrides the default in the script

if [ ! -z "$JAVA_PATH" ] ; then
    jdkhome=$JAVA_PATH
fi

#
# parse arguments
#

while [ $# -gt 0 ] ; do
    case "$1" in
        -h|-help) cat <<EOF
Usage: $0 {options} arguments

Options can be

   -h -help
        shows usage
   -jdkhome <path>
        specifies the JDK directory

   -hotspot
   -classic
   -native
   -green
        specifies the type of JVM
        
   -J<jvm_options>
        passes <jvm_option> to JVM
   -userdir <path>
        specifies userdir
   -cp:p <classpath>
        prepends <classpath> to IDE's classpath
   -cp:a <classpath>
        appends <classpath> to IDE's classpath

All other options and arguments are passed to the IDE.
See documentations for details

EOF
exit 1
;;
        -jdkhome) shift; if [ $# -gt 0 ] ; then jdkhome=$1; fi;;
        -userdir) shift; if [ $# -gt 0 ] ; then userdir=$1; fi;;
        -cp|-cp:a)
            shift;
            if [ $# -gt 0 ] ; then
                if [ ! -z "$postfixcp" ] ; then postfixcp="$postfixcp:" ; fi
                postfixcp=$postfixcp$1;
            fi
            ;;
        
        -cp:p)
            shift;
            if [ $# -gt 0 ] ; then
                if [ ! -z "$prefixcp" ] ; then prefixcp="$prefixcp:" ; fi
                prefixcp=$prefixcp$1;
            fi
            ;;
        
        -hotspot|-classic|-native|-green) thread_flag=$1;;
        -J-hotspot|-J-classic|-J-native|-J-green) thread_flag=`expr $1 : '-J\(.*\)'`;;
        -J*) jopt=`expr $1 : '-J\(.*\)'`; jargs="$jargs \"$jopt\"";;
        *) args="$args \"$1\"" ;;
    esac
    shift
done

#
# check JDK
#

if [ -z "$jdkhome" ] ; then
    echo "Cannot find JDK. Please set the JAVA_PATH environment variable to point"
    echo "to your JDK installation directory, or use the -jdkhome switch"
    echo ""
    exit 1
fi

if [ ! -x "${jdkhome}/bin/java" ] ; then
    echo "Cannot find JDK at ${jdkhome}. Please set the JAVA_PATH"
    echo "environment variable to point to your JDK installation directory,"
    echo "or use the -jdkhome switch"
    echo ""
    exit 1
fi

#
# check userdir
#

if [ ! -z "$userdir" ] ; then
    if id | grep 'uid=0[^0-9]' >/dev/null; then
        echo "You are running Forte for Java as root. Configurations, updated modules"
        echo "and possibly development files will be stored in the shared installation"
        printf "directory. Continue? (y/n): "
        read answer
        while [ $answer != y -a $answer != Y -a $answer != n -a $answer != N ] ; do
            printf "Please answer y or n: "
            read answer
        done
        if [ $answer != y -a $answer != Y ] ; then
            exit 1
        fi
        userdir=""
    else

        #
        # setup userdir if needed
        
        echo "Using ${userdir} as the Forte for Java user directory...";

        if [ ! -d "${userdir}/system" ] ; then
            echo "Forte for Java user directory does not exist."
            echo "Setting up this user for Forte for Java..."

            mkdir -p "${userdir}" 2>/dev/null
            cp -r "${ffjhome}/Development" "${userdir}"
            
            mkdir "${userdir}/system"
            touch "${userdir}/system/project.last_hidden"
            touch "${userdir}/system/project.basic_hidden"
            mkdir "${userdir}/system/Projects" 2>/dev/null
            touch "${userdir}/system/Projects/workspace.ser_hidden"
            
            mkdir "${userdir}/modules"
            mkdir "${userdir}/lib"
            mkdir "${userdir}/lib/ext"
            mkdir "${userdir}/lib/patches"
        fi
        
        jargs="$jargs -Dnetbeans.user=$userdir"

    fi
fi

#
# main loop
#

while true; do

    #
    # build CLASSPATH
    #
    
    cp=""

    #
    # userdir comes first
    #
    
    if [ ! -z "$userdir" ] ; then
        base=$userdir
        
        # patches
        
        for ex in jar zip ; do
            if [ "`echo ${base}/lib/patches/*.$ex`" != "${base}/lib/patches/*.$ex" ] ; then
                for x in ${base}/lib/patches/*.$ex ; do
                    if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                    cp="$cp$x"
                done
            fi
        done

        # ext

        for ex in jar zip ; do
            if [ "`echo ${base}/lib/ext/*.$ex`" != "${base}/lib/ext/*.$ex" ] ;then
                for x in ${base}/lib/ext/*.$ex ; do
                    if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                    cp="${cp}$x"
                done
            fi
        done

        # ffj jars

        if [ -d "$base/lib" ] ; then
            if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
            cp="${cp}${base}/lib"
        fi
    
        for ex in jar zip ; do
            if [ "`echo ${base}/lib/*.$ex`" != "${base}/lib/*.$ex" ] ;then
                for x in ${base}/lib/*.$ex ; do
                    if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                        cp="${cp}$x"
                done
            fi
        done

    fi

    #
    # ffjhome comes second
    #
    
    base=$ffjhome
        
    # patches
        
    for ex in jar zip ; do
        if [ "`echo ${base}/lib/patches/*.$ex`" != "${base}/lib/patches/*.$ex" ] ; then
            for x in ${base}/lib/patches/*.$ex ; do
                if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                cp="$cp$x"
            done
        fi
    done
    
    # ext

    for ex in jar zip ; do
        if [ "`echo ${base}/lib/ext/*.$ex`" != "${base}/lib/ext/*.$ex" ] ;then
            for x in ${base}/lib/ext/*.$ex ; do
                if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                cp="${cp}$x"
            done
        fi
    done

    # ffj jars

    if [ -d "$base/lib" ] ; then
        if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
        cp="${cp}${base}/lib"
    fi
    
    for ex in jar zip ; do
        if [ "`echo ${base}/lib/*.$ex`" != "${base}/lib/*.$ex" ] ;then
            for x in ${base}/lib/*.$ex ; do
                if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                cp="${cp}$x"
            done
        fi
    done

    #
    # JDK tools
    #
    
    for ex in jar zip ; do
        if [ "`echo ${jdkhome}/lib/*.$ex`" != "${jdkhome}/lib/*.$ex" ] ;then
            for x in ${jdkhome}/lib/*.$ex ; do
                if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                cp="${cp}$x"
            done
        fi
    done

    #
    # user-specified prefix and postfix CLASSPATH
    #
    
    if [ ! -z "${prefixcp}" ] ; then
        cp="${prefixcp}:$cp"
    fi
    
    if [ ! -z "${postfixcp}" ] ; then
        cp="$cp:${postfixcp}"
    fi

    #
    # ${CLASSPATH}
    #

    if [ ! -z "${CLASSPATH}" ] ; then
        cp="$cp:${CLASSPATH}"
    fi
    
    #
    # let's go
    #
    
    eval $jdkhome/bin/java $thread_flag $jargs -classpath "\"$cp\"" $ide $args

    # AutoUpdate exit?
    
    rc=$?
    if [ $rc -ne 66 ] ; then
        exit $rc
    fi

    # runs updater
    
    eval $jdkhome/bin/java $thread_flag $jargs -classpath "\"$cp\"" $updater
done
